mangadap.proc.spatiallybinnedspectra module
===========================================

.. automodule:: mangadap.proc.spatiallybinnedspectra
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
